@@ -22,12 +22,19 @@
 #ifndef _RFID_H_
 #define _RFID_H_
 
+#include <signal.h>
 #include <s6350.h>
 
 /*
  * Assume that a RFID transponder can hold a maximum of 32 bytes.
  */
 #define RFID_TRANSPONDER_DATA_SIZE 32
+/*
+ * Size of a string holding hexadecimal representation of 
+ * a RFID transponder identity, with separators and trailing 
+ * NULL.
+ */
+#define RFID_TRANSPONDER_HEX_ID_SIZE 32
 
 /*
  * RFID transponder identity and data.
@@ -67,6 +74,7 @@ typedef struct {
 				   reported by the RFID reader. */
   int verbose;			/* Control verbosity level of
 				   functions. */
+  sigset_t sigset;		/* Saved signal handlers state. */
 } rfid_t;
 
 /*
