@@ -498,8 +498,12 @@ int s6350_write_block(s6350_t* s6350, const s6350_transponder_t* transponder, co
   request[S6350_WRITE_BLOCK_REQUEST_BLOCK_NUMBER] = block->block_number;
   memcpy(request + S6350_WRITE_BLOCK_REQUEST_DATA, block->data, transponder->bytes_per_block);
 
-  if(write_request(s6350, S6350_COMMAND_COMBINE(S6350_COMMAND_WRITE_BLOCK, S6350_COMMAND_FLAGS_ADDRESS), request, request_size) < 0)
+  if(write_request(s6350, S6350_COMMAND_COMBINE(S6350_COMMAND_WRITE_BLOCK, S6350_COMMAND_FLAGS_ADDRESS), request, request_size) < 0) {
+    free(request);
     return -1;
+  }
+
+  free(request);
 
   if(read_answer(s6350, &buffer, &buffer_size) < 0)
     return -1;
@@ -680,6 +684,15 @@ int s6350_init(s6350_t* s6350)
     return -1;
   }
 
+  if(lockf(s6350->fd, F_TLOCK, 0) < 0) {
+    if(errno == EAGAIN)
+      s6350->error = EEXIST;
+    else
+      s6350->error = errno;
+    close(s6350->fd);
+    return -1;
+  }
+  
   /*
    * Init serial line
    */
