@@ -29,6 +29,7 @@
 #include <signal.h>
 #include <string.h>
 #include <memory.h>
+#include <errno.h>
 
 #include "rfid.h"
 
@@ -150,6 +151,7 @@ int main(int argc, char** argv)
   {
     rfid_transponder_t transponder;
     const s6350_transponder_t* info = &transponder.info;
+    memset(&transponder, '\0', sizeof(rfid_transponder_t));
     memcpy(transponder.data, test_string, strlen(test_string));
     transponder.data_length = strlen(test_string);
     if(rfid_write(&rfid, &transponder) < 0) {
@@ -177,6 +179,19 @@ bytes_per_block = %d\n\
 	    info->bytes_per_block
 	    );
   }
+  alarm(5);
+  {
+    rfid_transponder_t transponder;
+    s6350_transponder_t* info = &transponder.info;
+    memset(&transponder, '\0', sizeof(rfid_transponder_t));
+    /* Fake manufacturer, unlikely to match an existing one to trigger failure. */
+    info->manufacturer = 1;
+    if(rfid_write(&rfid, &transponder) >= 0 ||
+       rfid.error != EXDEV) {
+      report_error(&rfid, "rfid_write (EXDEV was expected)");
+      return -1;
+    }
+  }
   alarm(0);
   
   if(signal(SIGALRM, timeout_read) < 0) {
